@@ -1137,7 +1137,7 @@ class Account(ModelSQL, ModelView):
             logger.error("charge.refund.updated: No refund '%s'", rf['id'])
         for refund in refunds:
             if rf['status'] == 'pending':
-                Refund.processing([refund])
+                Refund.process([refund])
             elif rf['status'] == 'succeeded':
                 Refund.succeed([refund])
             elif rf['status'] in {'failed', 'canceled'}:
@@ -1688,8 +1688,7 @@ class Customer(CheckoutMixin, DeactivableMixin, ModelSQL, ModelView):
                 payment_methods = stripe.PaymentMethod.list(
                     api_key=self.stripe_account.secret_key,
                     stripe_version=STRIPE_VERSION,
-                    customer=self.stripe_customer_id,
-                    type='card')
+                    customer=self.stripe_customer_id)
             except (stripe.error.RateLimitError,
                     stripe.error.APIConnectionError) as e:
                 logger.warning(str(e))
@@ -1709,6 +1708,8 @@ class Customer(CheckoutMixin, DeactivableMixin, ModelSQL, ModelView):
                 name += ' ****' + card.last4
             if card.exp_month and card.exp_year:
                 name += ' %s/%s' % (card.exp_month, card.exp_year)
+        elif payment_method.type == 'sepa_debit':
+            name = '****' + payment_method.sepa_debit.last4
         return name
 
     @property
